#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant
version:              0.20.3.0
visibility:           public
id:                   servant-0.20.3.0-4N5aDL3IjARKTCNiquvhCG
key:                  servant-0.20.3.0-4N5aDL3IjARKTCNiquvhCG
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:             A family of combinators for defining webservices APIs
description:
    A family of combinators for defining webservices APIs and serving them
    .
    You can learn about the basics in the <http://docs.servant.dev/en/stable/tutorial/index.html tutorial>.
    .
    <https://github.com/haskell-servant/servant/blob/master/servant/CHANGELOG.md CHANGELOG>

category:             Servant, Web
abi:                  027a4bfabf665ed531def4c8e5f4504b
exposed:              True
exposed-modules:
    Servant.API Servant.API.Alternative Servant.API.BasicAuth
    Servant.API.Capture Servant.API.ContentTypes
    Servant.API.Description Servant.API.Empty
    Servant.API.Experimental.Auth Servant.API.Fragment
    Servant.API.Generic Servant.API.Header Servant.API.Host
    Servant.API.HttpVersion Servant.API.IsSecure Servant.API.Modifiers
    Servant.API.MultiVerb Servant.API.NamedRoutes
    Servant.API.QueryParam Servant.API.QueryString Servant.API.Range
    Servant.API.Raw Servant.API.RemoteHost Servant.API.ReqBody
    Servant.API.ResponseHeaders Servant.API.ServerSentEvents
    Servant.API.Status Servant.API.Stream Servant.API.Sub
    Servant.API.TypeErrors Servant.API.TypeLevel
    Servant.API.TypeLevel.List Servant.API.UVerb
    Servant.API.UVerb.Union Servant.API.Vault Servant.API.Verbs
    Servant.API.WithNamedContext Servant.API.WithResource Servant.Links
    Servant.Test.ComprehensiveAPI Servant.Types.Internal.Response
    Servant.Types.SourceT

import-dirs:          /usr/lib/ghc-9.6.6/site-local/servant-0.20.3.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/servant-0.20.3.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/servant-0.20.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant
hs-libraries:         HSservant-0.20.3.0-4N5aDL3IjARKTCNiquvhCG
depends:
    QuickCheck-2.15.0.1-IEDVvHXQ1Jd7OqAH4jP2Br
    aeson-2.2.2.0-Kh0pDn2f78S4mLhsXsZzzT
    attoparsec-0.14.4-9B3gn5pX08KJB1CStsvQz6 base-4.18.2.1
    bifunctors-5.6.3-45158ElRJNG4NCLPYvAitP bytestring-0.11.5.3
    case-insensitive-1.2.1.0-2w7xRwFPLfwFgOPFogdG9O
    constraints-0.14.3-4pd8fFxkgIh4nMxZM0BMF containers-0.6.7
    deepseq-1.4.8.1 generics-sop-0.5.1.4-Jm3azQ1bHSLFwLmIcDOhGt
    http-api-data-0.6.1-1xw9sKY2pnsL9616EKbdpw
    http-media-0.8.1.1-9VuUBgxNk6uBCjPfeJX9aK
    http-types-0.12.4-KOR1gLg6ER2IlcqJ0qNtQq
    mmorph-1.2.2-I879kMQXeoiA7V1mSxl9UH mtl-2.3.1
    network-uri-2.6.4.2-9CHKirNVw9rJ9Z87o3gbmr
    singleton-bool-0.1.8-FS9OCkJMJ5IFhU96w1uB5m
    sop-core-0.5.0.2-1KOi1hjK2a7LcGI7gMT7tS text-2.0.2
    transformers-0.6.1.0 vault-0.3.1.6-GpEoifvtFnZC2iN22L9KJY

haddock-interfaces:   /usr/share/doc/haskell-servant/html/servant.haddock
haddock-html:         /usr/share/doc/haskell-servant/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

